@@ -16,9 +16,9 @@
 //! assert_eq!("foobar".to_string().substring(1,6), "oobar");
 //! ```
 //!
-//! As Rust strings are UTF-8, the algorithm for finding a character substring is `O(n)`, where `n`
-//! is the byte length of the string. This is due to characters not being of predictible byte
-//! lengths.
+//! As Rust strings are UTF-8 encoded, the algorithm for finding a character substring is `O(n)`,
+//! where `n` is the byte length of the string. This is due to characters not being of predictible
+//! byte lengths.
 
 /// Provides a `substring` method.
 ///
@@ -81,4 +81,9 @@ mod tests {
     fn test_start_and_end_equal() {
         assert_eq!("foobar".substring(3, 3), "");
     }
+    
+    #[test]
+    fn test_multiple_byte_characters() {
+        assert_eq!("fõøbα®".substring(2, 5), "øbα");
+    }
 }
